@@ -25,13 +25,15 @@
 /* Free Software Foundation, Inc., 59 Temple Place - Suite 330, */
 /* Boston, MA 02111-1307, USA.                                  */
 /****************************************************************/
+#define _BSD_SOURCE
+
 #include "config.h"
 
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
-#include <gphoto2.h>
-#include <gphoto2-endian.h>
+#include <gphoto2/gphoto2.h>
+#include "gphoto2-endian.h"
 
 #include "spca50x.h"
 #include "spca50x-registers.h"
