@@ -1,5 +1,5 @@
 /** \file
- * Convenience header for gphoto2
+ * \brief Convenience header for gphoto2
  *
  * \author Copyright 2001 Lutz Mller <lutz@users.sf.net>
  *
@@ -45,14 +45,9 @@ extern "C" {
 #include <gphoto2/gphoto2-port-log.h>
 #include <gphoto2/gphoto2-port-result.h>
 
-#include <gphoto2/gphoto2-result.h>
-#include <gphoto2/gphoto2-camera.h>
 #include <gphoto2/gphoto2-file.h>
-#include <gphoto2/gphoto2-filesys.h>
 #include <gphoto2/gphoto2-library.h>
-#include <gphoto2/gphoto2-list.h>
 #include <gphoto2/gphoto2-setting.h>
-#include <gphoto2/gphoto2-widget.h>
 
 #ifdef __cplusplus
 }
